Backend Interfaces
==================

See :class:`.ACSVSettings` for information on how to
configure the default computational backends. The module
:mod:`.sage_acsv.groebner` is the entrypoint for Groebner basis
computations.

.. toctree::
   :maxdepth: 2

   backends/default
   backends/macaulay2
   backends/msolve